@@ -15,7 +15,7 @@ use vars qw/@ISA/;
 use DBI;
 
 
-our $VERSION = '0.093';
+our $VERSION = '0.095';
 
 
 
@@ -176,18 +176,21 @@ sub tree {
 }
 
 
-=item C<timestamp([($section, $storyname, $commentpath)])>
+=item C<timestamp([($sectionid, $storyname, $commentpath)|Time::Piece])>
 
-The timestamp method will retrieve the timestamp of the comment. If
-the timestamp has been loaded earlier from the data storage (for
-example by the load method), you need not supply any arguments. If the
-timestamp is not available, you must supply the section, storyname and
-commenpath identifiers, the method will then load it into the data
-structure first.
+The timestamp method will retrieve or set the timestamp of the
+comment. If the timestamp has been loaded earlier from the data
+storage (for example by the load method), you need not supply any
+arguments. If the timestamp is not available, you must supply the
+sectionid, storyname and commentpath identifiers, the method will then
+load it into the data structure first.
 
-The timestamp method will return a Time::Piece object with the
+The timestamp method will return a L<Time::Piece> object with the
 requested time information.
 
+To set the timestamp, you must supply a L<Time::Piece> object, the
+timestamp is set to the time given by that object.
+
 =back
 
 =cut
@@ -195,9 +198,14 @@ requested time information.
 
 sub timestamp {
   my $self = shift;
+  my $arg = shift;
+  if (ref($arg) eq 'Time::Piece') {
+    ${$self}{'timestamp'} = $arg->datetime;
+    return $self;
+  }
   if (! ${$self}{'timestamp'}) {
-    my ($section, $storyname, $commentpath) = @_;
-    $self->load(what => 'timestamp', limit => {sectionid   => $section,
+    my ($storyname, $commentpath) = @_;
+    $self->load(what => 'timestamp', limit => {sectionid   => $arg,
 					       storyname   => $storyname,
 					       commentpath => $commentpath 
 					      });
@@ -208,6 +216,9 @@ sub timestamp {
 }
 
 
+
+
+
 1;
 
 =head1 STORED DATA
