@@ -11,7 +11,7 @@ use Carp;
 # module.
 
 
-our $VERSION = '0.2';
+our $VERSION = '0.4';
 
 =head1 NAME
 
@@ -66,6 +66,7 @@ use Apache::AxKit::Exception;
 use Apache::AxKit::Provider;
 
 use AxKit;
+use AxKit::App::TABOO;
 use AxKit::App::TABOO::Data::Story;
 use AxKit::App::TABOO::Data::Plurals::Stories;
 use AxKit::App::TABOO::Data::Category;
@@ -73,8 +74,6 @@ use AxKit::App::TABOO::Data::Plurals::Categories;
 use AxKit::App::TABOO::Data::Article;
 use AxKit::App::TABOO::Data::Plurals::Articles;
 
-use Apache::AxKit::Plugin::BasicSession;
-
 
 sub init {
   my $self = shift;
@@ -83,13 +82,14 @@ sub init {
   
   AxKit::Debug(10, "[Classification] Request object: " . $r->as_string);
   AxKit::Debug(8, "[Classification] Provider using URI " . $r->uri);
-  
- 
+
   $self->{uri} = $r->uri;
   my @uri = split('/', $r->uri);
   splice(@uri, 0, 2); # The first part is just a keyword,
   $self->{cats} = \@uri;
 
+  $self->{session} = AxKit::App::TABOO::session($r);
+
   AxKit::Debug(9, "[Classification] Data parsed in init: " . Dumper($self));
   return $self;
 }
@@ -113,7 +113,7 @@ sub process {
     $self->{stories} = AxKit::App::TABOO::Data::Plurals::Stories->new();
     unless ($self->{articles}->incat(@{$self->{cats}})) {
       $self->{articles} = undef;
-      unless ($self->{stories}->exists(catname => @{$self->{cats}})) { 
+      unless ($self->{stories}->exists(primcat => @{$self->{cats}})) { 
 	$self->{exists} = 0;
       }
     }
@@ -133,9 +133,8 @@ sub exists {
 
 
 sub key {
-  no warnings; # To avoid warning when no credential_0 exists
   my $self = shift;
-  return $self->{uri} . "/" . $Apache::AxKit::Plugin::BasicSession::session{credential_0};
+  return $self->{uri} . "/" . AxKit::App::TABOO::loggedin($self->{session});
 }
 
 
@@ -158,11 +157,12 @@ sub get_dom {
 					     return_code => 404,
 					     -text => "Category " . $self->{catnotfound} . " was not found");
     }
-    warn "ANT: " . Dumper($self);
+#    warn "ANT: " . Dumper($self);
+    my $authlevel = AxKit::App::TABOO::authlevel($self->{session});
     if (scalar(@{$self->{cats}}) == 1) {
       my %limit;
-      if (! defined($Apache::AxKit::Plugin::BasicSession::session{authlevel})
-	  || ($Apache::AxKit::Plugin::BasicSession::session{authlevel} < 4)) {
+      if (! defined($authlevel)
+	  || ($authlevel < 4)) {
 	$limit{'editorok'} = 1;
       } elsif ($self->{editor}) {
 	$limit{'editorok'} = 0;
@@ -189,8 +189,8 @@ sub get_dom {
     my $anyarticles = 0;
     if($self->{articles}) {
       my %limit;
-      if (! defined($Apache::AxKit::Plugin::BasicSession::session{authlevel})
-	  || ($Apache::AxKit::Plugin::BasicSession::session{authlevel} < 4)) {
+      if (! defined($authlevel)
+	  || ($authlevel < 4)) {
 	$limit{'editorok'} = 1;
 	$limit{'authorok'} = 1;
       }
@@ -202,11 +202,11 @@ sub get_dom {
       $self->{articles}->addformatinfo;
       $self->{articles}->write_xml($doc, $rootel);
     }
-    warn Dumper($self->{stories});
-    warn Dumper($self->{articles});
+#    warn Dumper($self->{stories});
+#    warn Dumper($self->{articles});
     
     unless (($anyarticles) || (defined($self->{stories}))) {
-      if (defined($Apache::AxKit::Plugin::BasicSession::session{authlevel})) {
+      if (defined($authlevel)) {
 	throw Apache::AxKit::Exception::Retval(
 					       return_code => 403,
 					       -text => "Articles or stories exist, but are only accessible to editors.");
